@@ -140,7 +140,7 @@ def remakeRawSchema(rawSchemaJson,csvFolder="",gClient=None):
             nodeItemGInfoDfList=[]
             for nodeIdI in range(0,len(nodeIdList),searchBatch):
                 queryStrList=[]
-                for nodeIdIItem in range(nodeIdI,nodeIdI+searchBatch):
+                for nodeIdIItem in range(nodeIdI,min(nodeIdI+searchBatch,len(nodeIdList))):
                     queryStrItem="LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}=='{nodeIdVal}'| FETCH PROP ON {nodeType} $-.VertexID".format(nodeType=nodeType,
                                                                                                                                                 nodeIdAttr=nodeIdAttr,
                                                                                                                                                 nodeIdVal=nodeIdList[nodeIdIItem])
